"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Service = void 0;
const superagent_1 = __importDefault(require("superagent"));
const crypto_1 = __importDefault(require("crypto"));
const buffer_1 = require("buffer");
const oauth_connector_1 = require("@fusebit-int/oauth-connector");
class Service extends oauth_connector_1.OAuthConnector.Service {
    getEventsFromPayload(ctx) {
        const event = ctx.req.headers['x-github-event'];
        const type = `${event}.${ctx.req.body.action}`;
        return [{ data: ctx.req.body, type }];
    }
    getAuthIdFromEvent(ctx, event) {
        var _a, _b;
        return (_b = (_a = event === null || event === void 0 ? void 0 : event.data) === null || _a === void 0 ? void 0 : _a.sender) === null || _b === void 0 ? void 0 : _b.id;
    }
    async validateWebhookEvent(ctx) {
        const payload = ctx.req.body;
        const signatureHeader = ctx.req.headers['x-hub-signature-256'];
        if (payload && signatureHeader) {
            const requestBody = JSON.stringify(payload);
            const signatureBuffer = buffer_1.Buffer.from(signatureHeader);
            const signingAlgorithm = 'sha256';
            const sign = `${signingAlgorithm}=${crypto_1.default
                .createHmac(signingAlgorithm, ctx.state.manager.config.configuration.signingSecret)
                .update(requestBody)
                .digest('hex')}`;
            const verificationBuffer = buffer_1.Buffer.from(sign);
            if (signatureBuffer.length !== verificationBuffer.length) {
                return false;
            }
            const isValid = crypto_1.default.timingSafeEqual(signatureBuffer, verificationBuffer);
            return isValid;
        }
        return false;
    }
    async initializationChallenge(ctx) {
        return false;
    }
    async getTokenAuthId(ctx, token) {
        var _a;
        const userResponse = await superagent_1.default
            .get('https://api.github.com/user')
            .set('User-Agent', `fusebit/${ctx.state.params.entityId}`)
            .set('Authorization', `Bearer ${token.access_token}`)
            .set('Accept', 'application/vnd.github.v3+json');
        return (_a = userResponse === null || userResponse === void 0 ? void 0 : userResponse.body) === null || _a === void 0 ? void 0 : _a.id;
    }
    getWebhookEventType(event) {
        return event.type;
    }
}
exports.Service = Service;
//# sourceMappingURL=Service.js.map